@@ -1,12 +1,12 @@
 package App::chartimes ;  
-our $VERSION = '0.030' ; 
-our $DATE = '2024-03-14T16:51+09:00' ; 
+our $VERSION = '0.031' ; 
+our $DATE = '2024-03-16T00:24+09:00' ; 
 
 =encoding utf8
 
 =head1 NAME
 
-App::chartimes
+App::chartimes - 各文字iをj個持つ行が、入力全体に何行発生したか行列状に表示する。jの意味を、同じiが最長何回連続して発生したか意味を変えるオプションもある。
 
 =head1 SYNOPSIS
 
